/*
 * Name:     CDrawable.h
 *
 *
 * Class:    CDrawable
 * Impl:     CDrawable.cpp
 * Created : Feb 26, 2010
 * Author :  Kenji Aono
 */

#pragma once
#ifndef CDRAWABLE_H_
#define CDRAWABLE_H_

#include <list>

class CActor;

/*
 * Class:    CDrawable
 * 
 */
class CDrawable
{
public:
	CDrawable(const std::wstring &name);
	virtual ~CDrawable();

	void Place(wxPoint offset, double rotate);
	void AddChild(CDrawable *child);
	virtual void Draw(wxDC *dc) = 0;

	virtual bool HitTest(wxPoint pos) = 0;
	virtual bool IsMovable();
	void Move(wxPoint delta);

	void SetPosition(wxPoint p) {mPosition = p;}
	wxPoint GetPosition() const {return mPosition;}
	void SetName(const std::wstring &name) {mName = name;}
	std::wstring GetName() const {return mName;}
	virtual void SetRotation(double r) {mRotation = r;}
	double GetRotation() const {return mRotation;}
	void SetActor(CActor* a) {mActor = a;}
	CActor* GetActor() const {return mActor;}
	void SetParent(CDrawable* mommy) {mParent = mommy;}
	CDrawable* GetParent() const {return mParent;}

protected:
	wxPoint RotatePoint(wxPoint point, double angle);
	double mRotation;

private:
	CDrawable();

	wxPoint mPosition;
	std::wstring mName;
	CActor* mActor;
	std::list<CDrawable *> mChildren;
	CDrawable* mParent;

protected:
	wxPoint mPlacedPosition;
	double mPlacedR;
};

#endif /* CDRAWABLE_H_ */
