/*
 * Name:     CPolyDrawable.cpp
 *
 *
 * Class:    CPolyDrawable
 * Header:   CPolyDrawable.h
 * Created : Feb 26, 2010
 * Author :  Kenji Aono
 */

#include "wx/prec.h"
#include "CPolyDrawable.h"
#include <vector>

/*
 * Name :        CPolyDrawable::CPolyDrawable()
 * Description : PolyDrawable class constructor
 */
//CPolyDrawable::CPolyDrawable()
//{
//}

/*
 * Name :        CPolyDrawable::CPolyDrawable()
 * Description : Constructor for a polygon object.
 * Parameters :  name - The name of the object we are creating.
 * Returns :     none
 */
CPolyDrawable::CPolyDrawable(const std::wstring &name) : CDrawable(name)
{
    mColor = *wxBLACK;
}

/*
 * Name :        CPolyDrawable::~CPolyDrawable()
 * Description : PolyDrawable class destructor
 */
CPolyDrawable::~CPolyDrawable()
{
}

/*
 * Name :        CPolyDrawable::Draw()
 * Description : Draw our polygon.
 * Parameters :  dc - The device context
 * Returns :     none
 */
void CPolyDrawable::Draw(wxDC *dc)
{
    wxBrush brush(mColor);
    dc->SetBrush(brush);

    wxPen pen(mColor, 0);
    dc->SetPen(pen);

    // Transform the points
    std::vector<wxPoint> points;
    for(std::vector<wxPoint>::iterator p=mPoints.begin(); p!=mPoints.end(); p++)
    {
        points.push_back(RotatePoint(*p, mPlacedR) + mPlacedPosition);
    }

    dc->DrawPolygon((int)points.size(), &points[0]);

    dc->SetBrush(wxNullBrush);
    dc->SetPen(wxNullPen);
}

/*
 * Name :        CPolyDrawable::HitTest()
 * Description : Test to see if we hit this object.
 * Parameters :  pos - Click position
 * Returns :     true it hit
 */
bool CPolyDrawable::HitTest(wxPoint pos)
{
    // Transform the points
    std::vector<wxPoint> points;
    for(std::vector<wxPoint>::iterator p=mPoints.begin(); p!=mPoints.end(); p++)
    {
        points.push_back(RotatePoint(*p, mPlacedR) + mPlacedPosition);
    }

    wxRegion region((int)points.size(), &points[0], wxODDEVEN_RULE);
    return region.Contains(pos) == wxInRegion;
}
